src/hotspot/share/runtime/synchronizer.hpp
changeset 52703 e7fdc9d9c376
parent 51998 27b48d82272c
child 53244 9807daeb47c4
--- a/src/hotspot/share/runtime/synchronizer.hpp	Tue Nov 27 17:53:17 2018 -0500
+++ b/src/hotspot/share/runtime/synchronizer.hpp	Tue Nov 27 18:35:16 2018 -0500
@@ -35,9 +35,10 @@
 class ThreadsList;
 
 struct DeflateMonitorCounters {
-  int nInuse;          // currently associated with objects
-  int nInCirculation;  // extant
-  int nScavenged;      // reclaimed
+  int nInuse;             // currently associated with objects
+  int nInCirculation;     // extant
+  int nScavenged;         // reclaimed
+  double perThreadTimes;  // per-thread scavenge times
 };
 
 class ObjectSynchronizer : AllStatic {